Modules
- brute_
force - Brute-force (exact) k-NN.
- cagra
- CAGRA: a graph-based approximate nearest neighbors algorithm with state-of-the-art query throughput for both small and large batch sizes.
- filters
- Shared filter payloads for nearest-neighbor search APIs.
- ivf_
flat - IVF-Flat: an inverted-file index over uncompressed (“flat”) vectors. It
partitions the dataset into
n_listsclusters and, at query time, scans only then_probesclosest clusters — a simple knob to trade recall for speed. - ivf_pq
- IVF-PQ: an inverted-file index that product-quantizes the vectors. Like
IVF-Flat it partitions the dataset into
n_listsclusters and scans then_probesclosest at query time, but compresses each vector intopq_dimcodes ofpq_bitsbits — much smaller, slightly less accurate. - vamana
- Vamana: builds a DiskANN-style Vamana graph over a dataset.